@@ -31,13 +31,12 @@
 #include <X11/Xauth.h>
 #include <glib/gi18n.h>
 
-#include <vicious.h>
-
 #include "gdm.h"
 #include "cookie.h"
 #include "misc.h"
 #include "filecheck.h"
 #include "auth.h"
+#include "gdmconfig.h"
 
 /* Ensure we know about FamilyInternetV6 even if what we're compiling
    against doesn't */
@@ -50,16 +49,6 @@
 /* Local prototypes */
 static FILE *gdm_auth_purge (GdmDisplay *d, FILE *af, gboolean remove_when_empty);
 
-/* Configuration option variables */
-extern gchar *GdmServAuthDir;
-extern gchar *GdmUserAuthDir;
-extern gchar *GdmUserAuthFile;
-extern gchar *GdmUserAuthFB;
-extern gint  GdmUserMaxFile;
-extern gint  GdmRelaxPerms;
-extern gboolean GdmDebug;
-extern gboolean GdmNeverPlaceCookiesOnNFS;
-
 static void
 display_add_error (GdmDisplay *d)
 {
@@ -192,10 +181,10 @@ gdm_auth_secure_display (GdmDisplay *d)
     if (d->server_uid != 0) {
 	    int authfd;
 
-	    /* Note, Xnest can't use the ServAuthDir unless running as
+	    /* Note, Xnest can't use the GDM_KEY_SERV_AUTHDIR unless running as
 	     * root, which is rare anyway, unless the user is a wanker */
 
-	    d->authfile = g_build_filename (GdmUserAuthFB, ".gdmXXXXXX", NULL);
+	    d->authfile = g_build_filename (gdm_get_value_string (GDM_KEY_USER_AUTHDIR_FALLBACK), ".gdmXXXXXX", NULL);
 
 	    umask (077);
 	    authfd = g_mkstemp (d->authfile);
@@ -203,7 +192,7 @@ gdm_auth_secure_display (GdmDisplay *d)
 
 	    if G_UNLIKELY (authfd == -1) {
 		    gdm_error (_("%s: Could not make new cookie file in %s"),
-			       "gdm_auth_secure_display", GdmUserAuthFB);
+			       "gdm_auth_secure_display", gdm_get_value_string (GDM_KEY_USER_AUTHDIR_FALLBACK));
 		    g_free (d->authfile);
 		    d->authfile = NULL;
 		    return FALSE;
@@ -222,7 +211,7 @@ gdm_auth_secure_display (GdmDisplay *d)
 
 	    /* Make another authfile since the greeter can't read the server/user
 	     * readable file */
-	    d->authfile_gdm = gdm_make_filename (GdmServAuthDir, d->name, ".Xauth");
+	    d->authfile_gdm = gdm_make_filename (gdm_get_value_string (GDM_KEY_SERV_AUTHDIR), d->name, ".Xauth");
 	    af_gdm = gdm_safe_fopen_w (d->authfile_gdm);
 
 	    if G_UNLIKELY (af_gdm == NULL) {
@@ -239,7 +228,7 @@ gdm_auth_secure_display (GdmDisplay *d)
 	    }
     } else {
 	    /* gdm and xserver authfile can be the same, server will run as root */
-	    d->authfile = gdm_make_filename (GdmServAuthDir, d->name, ".Xauth");
+	    d->authfile = gdm_make_filename (gdm_get_value_string (GDM_KEY_SERV_AUTHDIR), d->name, ".Xauth");
 	    af = gdm_safe_fopen_w (d->authfile);
 
 	    if G_UNLIKELY (af == NULL) {
@@ -299,9 +288,9 @@ gdm_auth_secure_display (GdmDisplay *d)
 		    return FALSE;
 	    }
     }
-    ve_setenv ("XAUTHORITY", GDM_AUTHFILE (d), TRUE);
+    g_setenv ("XAUTHORITY", GDM_AUTHFILE (d), TRUE);
 
-    if G_UNLIKELY (GdmDebug)
+    if G_UNLIKELY (gdm_get_value_bool (GDM_KEY_DEBUG))
 	    gdm_debug ("gdm_auth_secure_display: Setting up access for %s - %d entries", 
 		       d->name, g_slist_length (d->auths));
 
@@ -507,7 +496,7 @@ get_local_auths (GdmDisplay *d)
 
     }
 
-    if G_UNLIKELY (GdmDebug)
+    if G_UNLIKELY (gdm_get_value_bool (GDM_KEY_DEBUG))
 	    gdm_debug ("get_local_auths: Setting up access for %s - %d entries", 
 		       d->name, g_slist_length (auths));
 
@@ -572,6 +561,8 @@ gdm_auth_user_add (GdmDisplay *d, uid_t user, const char *homedir)
     gint authfd;
     FILE *af;
     GSList *auths = NULL;
+    gchar *userauthdir;
+    gchar *userauthfile;
     gboolean ret = TRUE;
     gboolean automatic_tmp_dir = FALSE;
     gboolean authdir_is_tmp_dir = FALSE;
@@ -582,22 +573,6 @@ gdm_auth_user_add (GdmDisplay *d, uid_t user, const char *homedir)
     if (!d)
 	return FALSE;
 
-    gdm_debug ("gdm_auth_user_add: Adding cookie for %d", user);
-
-    /* Determine whether UserAuthDir is specified. Otherwise ~user is used */
-    if ( ! ve_string_empty (GdmUserAuthDir) &&
-	strcmp (GdmUserAuthDir, "~") != 0) {
-	    if (strncmp (GdmUserAuthDir, "~/", 2) == 0) {
-		    authdir = g_build_filename (homedir, &GdmUserAuthDir[2], NULL);
-	    } else {
-		    authdir = g_strdup (GdmUserAuthDir);
-		    automatic_tmp_dir = TRUE;
-		    authdir_is_tmp_dir = TRUE;
-	    }
-    } else {
-	    authdir = g_strdup (homedir);
-    }
-
     if (d->local_auths != NULL) {
 	    gdm_auth_free_auth_list (d->local_auths);
 	    d->local_auths = NULL;
@@ -610,6 +585,25 @@ gdm_auth_user_add (GdmDisplay *d, uid_t user, const char *homedir)
 	    return FALSE;
     }
 
+    gdm_debug ("gdm_auth_user_add: Adding cookie for %d", user);
+
+    userauthdir  = gdm_get_value_string (GDM_KEY_USER_AUTHDIR);
+    userauthfile = gdm_get_value_string (GDM_KEY_USER_AUTHFILE);
+
+    /* Determine whether UserAuthDir is specified. Otherwise ~user is used */
+    if ( ! ve_string_empty (userauthdir) &&
+	strcmp (userauthdir, "~") != 0) {
+	    if (strncmp (userauthdir, "~/", 2) == 0) {
+		    authdir = g_build_filename (homedir, &userauthdir[2], NULL);
+	    } else {
+		    authdir = g_strdup (userauthdir);
+		    automatic_tmp_dir = TRUE;
+		    authdir_is_tmp_dir = TRUE;
+	    }
+    } else {
+	    authdir = g_strdup (homedir);
+    }
+
 try_user_add_again:
 
     locked = FALSE;
@@ -619,10 +613,10 @@ try_user_add_again:
     if (authdir == NULL)
 	    d->userauth = NULL;
     else
-	    d->userauth = g_build_filename (authdir, GdmUserAuthFile, NULL);
+	    d->userauth = g_build_filename (authdir, userauthfile, NULL);
 
     user_auth_exists = (d->userauth != NULL &&
-			access (d->userauth, F_OK) == 0);
+			g_access (d->userauth, F_OK) == 0);
 
     /* Find out if the Xauthority file passes the paranoia check */
     /* Note that this is not very efficient, we stat the files over
@@ -632,8 +626,9 @@ try_user_add_again:
 
 	/* first the standard paranoia check (this checks the home dir
 	 * too which is useful here) */
-	! gdm_file_check ("gdm_auth_user_add", user, authdir, GdmUserAuthFile, 
-			  TRUE, FALSE, GdmUserMaxFile, GdmRelaxPerms) ||
+	! gdm_file_check ("gdm_auth_user_add", user, authdir, userauthfile, 
+			  TRUE, FALSE, gdm_get_value_int (GDM_KEY_USER_MAX_FILE),
+                          gdm_get_value_int (GDM_KEY_RELAX_PERM)) ||
 
 	/* now the auth file checking routine */
 	! gdm_auth_file_check ("gdm_auth_user_add", user, d->userauth, TRUE /* absentok */, NULL) ||
@@ -644,7 +639,8 @@ try_user_add_again:
 	/* try opening as root, if we can't open as root,
 	   then this is a NFS mounted directory with root squashing,
 	   and we don't want to write cookies over NFS */
-	(GdmNeverPlaceCookiesOnNFS && ! try_open_read_as_root (d->userauth))) {
+	(gdm_get_value_bool (GDM_KEY_NEVER_PLACE_COOKIES_ON_NFS) &&
+         ! try_open_read_as_root (d->userauth))) {
 
         /* if the userauth file didn't exist and we were looking at it,
 	   it likely exists now but empty, so just whack it
@@ -652,16 +648,16 @@ try_user_add_again:
 	    was of wrong permissions, but more likely this is
 	    file on NFS dir with root-squashing enabled) */
         if ( ! user_auth_exists && d->userauth != NULL)
-		unlink (d->userauth);
+		g_unlink (d->userauth);
 
-	/* No go. Let's create a fallback file in GdmUserAuthFB (/tmp)
-	 * or perhaps GdmUserAuth directory (usually would be /tmp) */
+	/* No go. Let's create a fallback file in GDM_KEY_USER_AUTHDIR_FALLBACK (/tmp)
+	 * or perhaps userauthfile directory (usually would be /tmp) */
 	d->authfb = TRUE;
 	g_free (d->userauth);
 	if (authdir_is_tmp_dir && authdir != NULL)
 		d->userauth = g_build_filename (authdir, ".gdmXXXXXX", NULL);
 	else
-		d->userauth = g_build_filename (GdmUserAuthFB, ".gdmXXXXXX", NULL);
+		d->userauth = g_build_filename (gdm_get_value_string (GDM_KEY_USER_AUTHDIR_FALLBACK), ".gdmXXXXXX", NULL);
 	authfd = g_mkstemp (d->userauth);
 
 	if G_UNLIKELY (authfd < 0 && authdir_is_tmp_dir) {
@@ -713,6 +709,8 @@ try_user_add_again:
 	af = gdm_safe_fopen_ap (d->userauth);
     }
 
+    g_free (authdir);
+
     if G_UNLIKELY (af == NULL) {
 	/* Really no need to clean up here - this process is a goner anyway */
 	gdm_error (_("%s: Could not open cookie file %s"),
@@ -730,8 +728,6 @@ try_user_add_again:
 		goto try_user_add_again;
 	}
 
-	g_free (authdir);
-
 	return FALSE; 
     }
 
@@ -789,8 +785,6 @@ try_user_add_again:
     gdm_debug ("gdm_auth_user_add: Done");
 
     umask (022);
-
-    g_free (authdir);
     return ret;
 }
 
@@ -820,14 +814,14 @@ gdm_auth_user_remove (GdmDisplay *d, uid_t user)
     /* If we are using the fallback cookie location, simply nuke the
      * cookie file */
     if (d->authfb) {
-	VE_IGNORE_EINTR (unlink (d->userauth));
+	VE_IGNORE_EINTR (g_unlink (d->userauth));
 	g_free (d->userauth);
 	d->userauth = NULL;
 	return;
     }
 
     /* if the file doesn't exist, oh well, just ignore this then */
-    if G_UNLIKELY (access (d->userauth, F_OK) != 0) {
+    if G_UNLIKELY (g_access (d->userauth, F_OK) != 0) {
 	g_free (d->userauth);
 	d->userauth = NULL;
 	return;
@@ -848,7 +842,8 @@ gdm_auth_user_remove (GdmDisplay *d, uid_t user)
      * to it. So we better play it safe... */
 
     if G_UNLIKELY ( ! gdm_file_check ("gdm_auth_user_remove", user, authdir, authfile, 
-			   TRUE, FALSE, GdmUserMaxFile, GdmRelaxPerms) ||
+			   TRUE, FALSE, gdm_get_value_int (GDM_KEY_USER_MAX_FILE),
+                           gdm_get_value_int (GDM_KEY_RELAX_PERM)) ||
 		    /* be even paranoider with permissions */
 		    ! gdm_auth_file_check ("gdm_auth_user_remove", user, d->userauth, FALSE /* absentok */, NULL)) {
 	    g_free (authdir);
@@ -995,7 +990,7 @@ gdm_auth_purge (GdmDisplay *d, FILE *af, gboolean remove_when_empty)
 
     if (remove_when_empty &&
 	keep == NULL) {
-	    VE_IGNORE_EINTR (unlink (d->userauth));
+	    VE_IGNORE_EINTR (g_unlink (d->userauth));
 	    return NULL;
     }
 
