@@ -221,7 +221,7 @@ gdm_daemonify (void)
 	gdm_fail (_("%s: setsid () failed: %s!"), "gdm_daemonify",
 		  strerror (errno));
 
-    VE_IGNORE_EINTR (chdir (gdm_get_value_string (GDM_KEY_SERV_AUTHDIR)));
+    VE_IGNORE_EINTR (g_chdir (gdm_get_value_string (GDM_KEY_SERV_AUTHDIR)));
     umask (022);
 
     VE_IGNORE_EINTR (close (0));
@@ -363,7 +363,7 @@ gdm_final_cleanup (void)
 		char *path;
 		gdm_connection_close (fifoconn);
 		path = g_build_filename (gdm_get_value_string (GDM_KEY_SERV_AUTHDIR), ".gdmfifo", NULL);
-		VE_IGNORE_EINTR (unlink (path));
+		VE_IGNORE_EINTR (g_unlink (path));
 		g_free (path);
 		fifoconn = NULL;
 	}
@@ -380,7 +380,7 @@ gdm_final_cleanup (void)
 
 	if (unixconn != NULL) {
 		gdm_connection_close (unixconn);
-		VE_IGNORE_EINTR (unlink (GDM_SUP_SOCKET));
+		VE_IGNORE_EINTR (g_unlink (GDM_SUP_SOCKET));
 		unixconn = NULL;
 	}
 
@@ -388,7 +388,7 @@ gdm_final_cleanup (void)
 
 	pidfile = gdm_get_value_string (GDM_KEY_PID_FILE);
 	if (pidfile != NULL) {
-		VE_IGNORE_EINTR (unlink (pidfile));
+		VE_IGNORE_EINTR (g_unlink (pidfile));
 	}
 
 #ifdef  HAVE_LOGINDEVPERM
@@ -408,7 +408,7 @@ deal_with_x_crashes (GdmDisplay *d)
 	    char *bin = ve_first_word (failsafe);
 	    /* Yay we have a failsafe */
 	    if ( ! ve_string_empty (bin) &&
-		access (bin, X_OK) == 0) {
+		g_access (bin, X_OK) == 0) {
 		    gdm_info (_("%s: Trying failsafe X "
 				"server %s"), 
 			      "deal_with_x_crashes",
@@ -424,7 +424,7 @@ deal_with_x_crashes (GdmDisplay *d)
 
     /* Eeek X keeps crashing, let's try the XKeepsCrashing script */
     if ( ! ve_string_empty (keepscrashing) &&
-	access (keepscrashing, X_OK|R_OK) == 0) {
+	g_access (keepscrashing, X_OK|R_OK) == 0) {
 	    pid_t pid;
 
 	    gdm_info (_("%s: Running the "
@@ -539,7 +539,7 @@ deal_with_x_crashes (GdmDisplay *d)
     /* if we have "open" we can talk to the user, not as user
      * friendly as the above script, but getting there */
     if ( ! just_abort &&
-	access (EXPANDED_LIBEXECDIR "/gdmopen", X_OK) == 0) {
+	g_access (EXPANDED_LIBEXECDIR "/gdmopen", X_OK) == 0) {
 	    /* Shit if we knew what the program was to tell the user,
 	     * the above script would have been defined and we'd run
 	     * it for them */
@@ -584,7 +584,7 @@ suspend_machine (void)
 		/* Also make a new process group */
 		setsid ();
 
-		VE_IGNORE_EINTR (chdir ("/"));
+		VE_IGNORE_EINTR (g_chdir ("/"));
 
 		/* short sleep to give some processing time to master */
 		usleep (1000);
@@ -612,7 +612,7 @@ change_to_first_and_clear (gboolean reboot)
 	g_setenv ("TERM", "linux", TRUE);
 
 	/* evil hack that will get the fonts right */
-	if (access ("/bin/bash", X_OK) == 0)
+	if (g_access ("/bin/bash", X_OK) == 0)
 		system ("/bin/bash -l -c /bin/true");
 
 	/* clear screen and set to red */
@@ -635,7 +635,7 @@ halt_machine (void)
 	gdm_info (_("Master halting..."));
 
 	gdm_final_cleanup ();
-	VE_IGNORE_EINTR (chdir ("/"));
+	VE_IGNORE_EINTR (g_chdir ("/"));
 
 #ifdef __linux__
 	change_to_first_and_clear (FALSE /* reboot */);
@@ -657,7 +657,7 @@ reboot_machine (void)
 	gdm_info (_("Master rebooting..."));
 
 	gdm_final_cleanup ();
-	VE_IGNORE_EINTR (chdir ("/"));
+	VE_IGNORE_EINTR (g_chdir ("/"));
 
 #ifdef __linux__
 	change_to_first_and_clear (TRUE /* reboot */);
@@ -1298,7 +1298,7 @@ gdm_get_our_runlevel (void)
 #ifdef __linux__
 	/* on linux we get our current runlevel, for use later
 	 * to detect a shutdown going on, and not mess up. */
-	if (access ("/sbin/runlevel", X_OK) == 0) {
+	if (g_access ("/sbin/runlevel", X_OK) == 0) {
 		char ign;
 		int rnl;
 		FILE *fp = popen ("/sbin/runlevel", "r");
@@ -1341,7 +1341,7 @@ gdm_make_global_cookie (void)
 	gdm_global_bcookie = (unsigned char *) faked.bcookie;
 
 	file = g_build_filename (gdm_get_value_string (GDM_KEY_SERV_AUTHDIR), ".cookie", NULL);
-	VE_IGNORE_EINTR (unlink (file));
+	VE_IGNORE_EINTR (g_unlink (file));
 
 	oldmode = umask (077);
 	fp = gdm_safe_fopen_w (file);
@@ -1427,7 +1427,7 @@ main (int argc, char *argv[])
     /* XDM compliant error message */
     if G_UNLIKELY (getuid () != 0) {
 	    /* make sure the pid file doesn't get wiped */
-	    gdm_fail (_("Only root wants to run gdm\n"));
+	    gdm_fail (_("Only root wants to run GDM\n"));
     }
 
     main_loop = g_main_loop_new (NULL, FALSE);
@@ -1459,7 +1459,7 @@ main (int argc, char *argv[])
     pidfile = gdm_get_value_string (GDM_KEY_PID_FILE);
 
     /* Check if another gdm process is already running */
-    if (access (pidfile, R_OK) == 0) {
+    if (g_access (pidfile, R_OK) == 0) {
 
         /* Check if the existing process is still alive. */
         gint pidv;
@@ -1474,7 +1474,7 @@ main (int argc, char *argv[])
 		gdm_set_value_string (GDM_KEY_PID_FILE, NULL);
 		pidfile = NULL;
 		VE_IGNORE_EINTR (fclose (pf));
-		gdm_fail (_("gdm already running. Aborting!"));
+		gdm_fail (_("GDM already running. Aborting!"));
 	}
 
 	if (pf != NULL)
@@ -1507,15 +1507,15 @@ main (int argc, char *argv[])
 
 	}
 
-	VE_IGNORE_EINTR (chdir (gdm_get_value_string (GDM_KEY_SERV_AUTHDIR)));
+	VE_IGNORE_EINTR (g_chdir (gdm_get_value_string (GDM_KEY_SERV_AUTHDIR)));
 	umask (022);
     }
     else
 	gdm_daemonify ();
 
 #ifdef sun
-    unlink (SDTLOGIN_DIR);
-    mkdir (SDTLOGIN_DIR, 0700);
+    g_unlink (SDTLOGIN_DIR);
+    g_mkdir (SDTLOGIN_DIR, 0700);
 #endif
 
     /* Signal handling */
@@ -2623,7 +2623,7 @@ handle_flexi_server (GdmConnection *conn, int type, const char *server,
 
 	bin = ve_first_word (server);
 	if (ve_string_empty (server) ||
-	    access (bin, X_OK) != 0) {
+	    g_access (bin, X_OK) != 0) {
 		g_free (bin);
 		if (conn != NULL)
 			gdm_connection_write (conn,
@@ -2802,7 +2802,7 @@ gdm_handle_user_message (GdmConnection *conn, const char *msg, gpointer data)
 {
 	gdm_debug ("Handling user message: '%s'", msg);
 
-	if (gdm_connection_get_message_count (conn) > 20) {
+	if (gdm_connection_get_message_count (conn) > GDM_SUP_MAX_CONNECTIONS) {
 		gdm_connection_write (conn, "ERROR 200 Too many messages\n");
 		gdm_connection_close (conn);
 		return;
@@ -2889,7 +2889,7 @@ gdm_handle_user_message (GdmConnection *conn, const char *msg, gpointer data)
 			name = g_strdup (GDM_STANDARD);
 		}
 
-		svr = gdm_find_x_server (name);
+		svr = gdm_find_xserver (name);
 		if G_UNLIKELY (svr == NULL) {
 			/* Don't print the name to syslog as it might be
 			 * long and dangerous */
@@ -3005,9 +3005,8 @@ gdm_handle_user_message (GdmConnection *conn, const char *msg, gpointer data)
 		g_string_append (msg, "\n");
 		gdm_connection_write (conn, msg->str);
 		g_string_free (msg, TRUE);
-/*
 	} else if (strcmp (msg, GDM_SUP_GET_SERVER_LIST) == 0) {
-		gchar *retval = gdm_get_x_servers ();
+		gchar *retval = gdm_get_xservers ();
 
 		if (retval != NULL) {
 			gdm_connection_printf (conn, "OK %s\n", retval);
@@ -3019,15 +3018,50 @@ gdm_handle_user_message (GdmConnection *conn, const char *msg, gpointer data)
 	} else if (strncmp (msg, GDM_SUP_GET_SERVER_DETAILS " ",
 		     strlen (GDM_SUP_GET_SERVER_DETAILS " ")) == 0) {
 		const char *server = &msg[strlen (GDM_SUP_GET_SERVER_DETAILS " ")];
-		gchar *retval = gdm_get_x_server_details (server);
-		if (retval != NULL) {
-			gdm_connection_printf (conn, "OK %s\n", retval);
-			g_free (retval);
+		gchar   **splitstr = g_strsplit (server, " ", 2);
+		GdmXserver  *svr   = gdm_find_xserver ((char *)splitstr[0]);
+
+		if (svr != NULL) {
+			if (g_strcasecmp (splitstr[1], "ID") == 0)
+			   gdm_connection_printf (conn, "OK %s\n", svr->id);
+			else if (g_strcasecmp (splitstr[1], "NAME") == 0)
+			   gdm_connection_printf (conn, "OK %s\n", svr->name);
+			else if (g_strcasecmp (splitstr[1], "COMMAND") == 0) 
+			   gdm_connection_printf (conn, "OK %s\n", svr->command);
+			else if (g_strcasecmp (splitstr[1], "PRIORITY") == 0)
+			   gdm_connection_printf (conn, "OK %d\n", svr->priority);
+			else if (g_strcasecmp (splitstr[1], "FLEXIBLE") == 0 &&
+                                 svr->flexible)
+			   gdm_connection_printf (conn, "OK true\n");
+			else if (g_strcasecmp (splitstr[1], "FLEXIBLE") == 0 &&
+                                 !svr->flexible)
+			   gdm_connection_printf (conn, "OK false\n");
+			else if (g_strcasecmp (splitstr[1], "CHOOSABLE") == 0 &&
+                                 svr->choosable)
+			   gdm_connection_printf (conn, "OK true\n");
+			else if (g_strcasecmp (splitstr[1], "CHOOSABLE") == 0 &&
+                                 !svr->choosable)
+			   gdm_connection_printf (conn, "OK false\n");
+			else if (g_strcasecmp (splitstr[1], "HANDLED") == 0 &&
+                                 svr->handled)
+			   gdm_connection_printf (conn, "OK true\n");
+			else if (g_strcasecmp (splitstr[1], "HANDLED") == 0 &&
+                                 !svr->handled)
+			   gdm_connection_printf (conn, "OK false\n");
+			else if (g_strcasecmp (splitstr[1], "CHOOSER") == 0 &&
+                                 svr->chooser)
+			   gdm_connection_printf (conn, "OK true\n");
+			else if (g_strcasecmp (splitstr[1], "CHOOSER") == 0 &&
+                                 !svr->chooser)
+			   gdm_connection_printf (conn, "OK false\n");
+			else
+			   gdm_connection_printf (conn, "ERROR 2 Key not valid\n");
+
+			g_strfreev (splitstr);
 		} else {
                		gdm_connection_printf (conn, "ERROR 1 Server not found\n");
 		}
  
-*/
 	} else if (strcmp (msg, GDM_SUP_GREETERPIDS) == 0) {
 		GString *msg;
 		GSList *li;
@@ -3278,39 +3312,33 @@ gdm_handle_user_message (GdmConnection *conn, const char *msg, gpointer data)
 #else
 		gdm_connection_write (conn, "ERROR 8 Virtual terminals not supported\n");
 #endif
-    } else if (strncmp (msg, GDM_SUP_ADD_DYNAMIC_DISPLAY " ",
-                 strlen (GDM_SUP_ADD_DYNAMIC_DISPLAY " ")) == 0) {
-        char *key;
+	} else if (strncmp (msg, GDM_SUP_ADD_DYNAMIC_DISPLAY " ",
+		   strlen (GDM_SUP_ADD_DYNAMIC_DISPLAY " ")) == 0) {
+		char *key;
 
-        key = g_strdup (&msg[strlen (GDM_SUP_ADD_DYNAMIC_DISPLAY " ")]);
-        g_strstrip (key);
+		key = g_strdup (&msg[strlen (GDM_SUP_ADD_DYNAMIC_DISPLAY " ")]);
+		g_strstrip (key);
+		handle_dynamic_server (conn, DYNAMIC_ADD, key);
+		g_free (key);
 
-        handle_dynamic_server (conn, DYNAMIC_ADD, key);
+	} else if (strncmp (msg, GDM_SUP_REMOVE_DYNAMIC_DISPLAY " ",
+		   strlen (GDM_SUP_REMOVE_DYNAMIC_DISPLAY " ")) == 0) {
+		char *key;
 
-        g_free (key);
+		key = g_strdup (&msg[strlen (GDM_SUP_REMOVE_DYNAMIC_DISPLAY " ")]);
+		g_strstrip (key);
+		handle_dynamic_server (conn, DYNAMIC_REMOVE, key);
+		g_free (key);
 
-    } else if (strncmp (msg, GDM_SUP_REMOVE_DYNAMIC_DISPLAY " ",
-                        strlen (GDM_SUP_REMOVE_DYNAMIC_DISPLAY " ")) == 0) {
-        char *key;
+	} else if (strncmp (msg, GDM_SUP_RELEASE_DYNAMIC_DISPLAYS " ",
+		   strlen (GDM_SUP_RELEASE_DYNAMIC_DISPLAYS " ")) == 0) {
 
-        key = g_strdup (&msg[strlen (GDM_SUP_REMOVE_DYNAMIC_DISPLAY " ")]);
-        g_strstrip (key);
+		char *key;
 
-        handle_dynamic_server (conn, DYNAMIC_REMOVE, key);
-
-        g_free (key);
-
-    } else if (strncmp (msg, GDM_SUP_RELEASE_DYNAMIC_DISPLAYS " ",
-                        strlen (GDM_SUP_RELEASE_DYNAMIC_DISPLAYS " ")) == 0) {
-
-        char *key;
-
-        key = g_strdup (&msg[strlen (GDM_SUP_RELEASE_DYNAMIC_DISPLAYS " ")]);
-        g_strstrip (key);
-
-        handle_dynamic_server (conn, DYNAMIC_RELEASE, key);
-
-        g_free (key);
+		key = g_strdup (&msg[strlen (GDM_SUP_RELEASE_DYNAMIC_DISPLAYS " ")]);
+		g_strstrip (key);
+		handle_dynamic_server (conn, DYNAMIC_RELEASE, key);
+		g_free (key);
 
 	} else if (strcmp (msg, GDM_SUP_VERSION) == 0) {
 		gdm_connection_write (conn, "GDM " VERSION "\n");
