@@ -20,11 +20,11 @@
  */
 
 #include "config.h"
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
+#include <glib/gi18n.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdio.h>
+#include <popt.h>
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <fcntl.h>
@@ -36,16 +36,16 @@
 #include <errno.h>
 #include <X11/Xauth.h>
 
-#include <viciousui.h>
-
 #include "gdm.h"
 #include "gdmcomm.h"
 #include "gdmcommon.h"
+#include "gdmconfig.h"
 
 static pid_t xnest_pid = 0;
 
 #ifdef ENABLE_IPV6
-static gboolean have_ipv6 () {
+static gboolean
+have_ipv6 () {
 	gint s;
 
 	s = socket (AF_INET6, SOCK_STREAM, 0);
@@ -91,7 +91,7 @@ get_free_display (void)
 			serv6_addr.sin6_addr =  in6addr_loopback;
 			serv6_addr.sin6_port = htons (6000 + i);
 
-			if (connect (sock, (struct sockaddr *)&serv6_addr, sizeof(serv6_addr)) >= 0 ||  errno != ECONNREFUSED) {
+			if (connect (sock, (struct sockaddr *)&serv6_addr, sizeof (serv6_addr)) >= 0 ||  errno != ECONNREFUSED) {
 				VE_IGNORE_EINTR (close (sock));
 				continue;
 			      }
@@ -133,13 +133,13 @@ get_free_display (void)
 		}
 
 		g_snprintf (buf, sizeof (buf), "/tmp/.X11-unix/X%d", i);
-		if (stat (buf, &s) == 0 &&
+		if (g_stat (buf, &s) == 0 &&
 		    s.st_uid != getuid ()) {
 			continue;
 		}
 
 		g_snprintf (buf, sizeof (buf), "/tmp/.X%d-lock", i);
-		if (stat (buf, &s) == 0 &&
+		if (g_stat (buf, &s) == 0 &&
 		    s.st_uid != getuid ()) {
 			continue;
 		}
@@ -178,7 +178,7 @@ static const struct poptOption options[] = {
 	{ "direct", 'd', POPT_ARG_NONE, &do_direct, 0, N_("Do direct query instead of indirect (chooser)"), NULL },
 	{ "broadcast", 'B', POPT_ARG_NONE, &do_broadcast, 0, N_("Run broadcast instead of indirect (chooser)"), NULL },
 	{ "background", 'b', POPT_ARG_NONE, &background, 0, N_("Run in background"), NULL },
-	{ "no-gdm-check", '\0', POPT_ARG_NONE, &no_gdm_check, 0, N_("Don't check for running gdm"), NULL },
+	{ "no-gdm-check", '\0', POPT_ARG_NONE, &no_gdm_check, 0, N_("Don't check for running GDM"), NULL },
 	{ NULL } 
 };
 
@@ -266,7 +266,7 @@ make_us_an_exec_vector (const char *xnest)
 	gboolean got_font_path = FALSE;
 	char *font_path = NULL;
 
-	if( ! ve_string_empty (xnest_binary))
+	if ( ! ve_string_empty (xnest_binary))
 		xnest = xnest_binary;
 
 	if (ve_string_empty (xnest))
@@ -469,60 +469,37 @@ main (int argc, char *argv[])
 	const char **args;
 	char *xnest;
 	char **execvec;
-	gchar *config_file, *config_prefix;
 	struct sigaction term;
+	int nextopt;
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
 	if (strcmp (base (argv[0]), "gdmXnest") == 0) {
-		GnomeProgram *program = gnome_program_init
-			("gdmXnest", VERSION, 
-			 LIBGNOMEUI_MODULE /* module_info */,
-			 argc, argv,
-			 GNOME_PARAM_POPT_TABLE, xnest_only_options,
-			 NULL);
-		g_object_get (G_OBJECT (program),
-			      GNOME_PARAM_POPT_CONTEXT, &ctx,
-			      NULL);	
+		gtk_init(&argc, &argv);
+		ctx = poptGetContext(NULL, argc, (const char**)argv, xnest_only_options, 0);
+		while ((nextopt = poptGetNextOpt(ctx)) > 0 || nextopt == POPT_ERROR_BADOPT);
 		no_query = TRUE;
 		no_gdm_check = TRUE;
 	} else {
-		GnomeProgram *program = gnome_program_init
-			("gdmXnestchooser", VERSION, 
-			 LIBGNOMEUI_MODULE /* module_info */,
-			 argc, argv,
-			 GNOME_PARAM_POPT_TABLE, options,
-			 NULL);
-		g_object_get (G_OBJECT (program),
-			      GNOME_PARAM_POPT_CONTEXT, &ctx,
-			      NULL);	
+		gtk_init(&argc, &argv);
+		ctx = poptGetContext(NULL, argc, (const char**)argv, options, 0);
+		while ((nextopt = poptGetNextOpt(ctx)) > 0 || nextopt == POPT_ERROR_BADOPT);
 	}
 
 	args = poptGetArgs (ctx);
 	if (args != NULL && args[0] != NULL)
 		host = args[0];
 
-	config_file = gdm_common_get_config_file ();
-	if (config_file == NULL) {
-		g_print (_("Could not access GDM configuration file.\n"));
-		_exit (1);
-	}
 
-	config_prefix = g_strdup_printf("=%s=/", config_file);
-	gnome_config_push_prefix (config_prefix);
-	xdmcp_enabled = gnome_config_get_bool (GDM_KEY_XDMCP);
-	honor_indirect = gnome_config_get_bool (GDM_KEY_INDIRECT);
-	pidfile = gnome_config_get_string (GDM_KEY_PID_FILE);
-	xnest = gnome_config_get_string (GDM_KEY_XNEST);
-	gnome_config_pop_prefix ();
-	g_free (config_file);
-	g_free (config_prefix);
+	xdmcp_enabled  = gdm_config_get_bool (GDM_KEY_XDMCP);
+	honor_indirect = gdm_config_get_bool (GDM_KEY_INDIRECT);
+	pidfile        = gdm_config_get_string (GDM_KEY_PID_FILE);
+	xnest          = gdm_config_get_string (GDM_KEY_XNEST);
 
 	/* complex and wonderous way to get the exec vector */
 	execvec = make_us_an_exec_vector (xnest);
-	g_free (xnest);
 
 	if (execvec == NULL) {
 		GtkWidget *d;
@@ -587,7 +564,6 @@ main (int argc, char *argv[])
 		pid = 0;
 		if (pidfile != NULL) {
 			VE_IGNORE_EINTR (fp = fopen (pidfile, "r"));
-			g_free (pidfile);
 		}
 		if (fp != NULL) {
 			int r;
@@ -683,7 +659,7 @@ main (int argc, char *argv[])
 	xnest_pid = 0;
 
 	socket = g_strdup_printf ("/tmp/.X11-unix/X%d", display);
-	unlink (socket);
+	g_unlink (socket);
 	g_free (socket);
 
 	if (no_query)
