@@ -55,7 +55,10 @@ GdkPixbuf *gdm_common_get_face          (const char *filename,
                                          guint       max_height);
 gchar*	gdm_common_get_config_file	(void);
 gboolean gdm_common_select_time_format	(void);
-void	setup_background_color		(gchar *bg_color);
-gchar*	gdm_get_welcomemsg		(void);
+void	gdm_common_setup_background_color (gchar *bg_color);
+gchar*	gdm_common_get_welcomemsg	(void);
+void	gdm_common_post_display_launch  (void);
+gchar*  gdm_common_expand_text          (const gchar *text);
+gchar*  gdm_common_get_clock            (struct tm **the_tm);
 
 #endif /* GDM_COMMON_H */
