@@ -25,6 +25,7 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <stdio.h>
+#include <popt.h>
 #include <sys/types.h>
 #include <signal.h>
 #include <sys/socket.h>
@@ -36,8 +37,6 @@
 #include <glib/gi18n.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
-#include <libgnome/libgnome.h> /* for gnome_config */
-#include <libgnomeui/libgnomeui.h> /* for gnome_program */
 
 #include "gdm.h"
 #include "gdmcomm.h"
@@ -531,62 +530,21 @@ check_for_users (void)
 }
 
 static void
-read_servers (gchar *config_file)
+read_servers (void)
 {
-	gpointer iter;
-	gchar *config_sections;
-	char *k;
+	GSList *li;
 
-	/* Find server definitions */
-	config_sections = g_strdup_printf ("=%s=/", config_file);
-	iter = gnome_config_init_iterator_sections (config_sections);
-	iter = gnome_config_iterator_next (iter, &k, NULL);
+        xservers = gdm_config_get_xservers (TRUE);
 
-	while (iter) {
-		if (strncmp (k, "server-", strlen ("server-")) == 0) {
-			char *section;
-			GdmXserver *svr;
+	for (li = xservers; li != NULL; li = li->next) {
+		GdmXserver *svr = li->data;
 
-			section = g_strdup_printf ("=%s=/%s/", config_file, k);
-			gnome_config_push_prefix (section);
+		if (strcmp (svr->id, GDM_STANDARD) == 0)
+			got_standard = TRUE;
 
-			if ( ! gnome_config_get_bool
-			     (GDM_KEY_SERVER_FLEXIBLE)) {
-				gnome_config_pop_prefix ();
-				g_free (section);
-				g_free (k);
-				iter = gnome_config_iterator_next (iter,
-								   &k, NULL);
-				continue;
-			}
-
-			svr = g_new0 (GdmXserver, 1);
-
-			svr->id = g_strdup (k + strlen ("server-"));
-			svr->name = gnome_config_get_string
-				(GDM_KEY_SERVER_NAME);
-			svr->command = gnome_config_get_string
-				(GDM_KEY_SERVER_COMMAND);
-			svr->flexible = TRUE;
-			svr->choosable = gnome_config_get_bool
-				(GDM_KEY_SERVER_CHOOSABLE);
-
-			g_free (section);
-			gnome_config_pop_prefix ();
-
-			if (strcmp (svr->id, GDM_STANDARD) == 0)
-				got_standard = TRUE;
-
-			if (server != NULL &&
-			    strcmp (svr->id, server) == 0)
-				chosen_server = g_strdup (svr->id);
-
-			xservers = g_slist_append (xservers, svr);
-		}
-
-		g_free (k);
-
-		iter = gnome_config_iterator_next (iter, &k, NULL);
+		if (server != NULL &&
+		    strcmp (svr->id, server) == 0)
+			chosen_server = g_strdup (svr->id);
 	}
 }
 
@@ -727,7 +685,7 @@ calc_pi (void)
 }
 
 struct poptOption options [] = {
-	{ "command", 'c', POPT_ARG_STRING, &send_command, 0, N_("Send the specified protocol command to gdm"), N_("COMMAND") },
+	{ "command", 'c', POPT_ARG_STRING, &send_command, 0, N_("Send the specified protocol command to GDM"), N_("COMMAND") },
 	{ "xnest", 'n', POPT_ARG_NONE, &use_xnest, 0, N_("Xnest mode"), NULL },
 	{ "no-lock", 'l', POPT_ARG_NONE, &no_lock, 0, N_("Do not lock current screen"), NULL },
 	{ "debug", 'd', POPT_ARG_NONE, &debug, 0, N_("Debugging output"), NULL },
@@ -743,27 +701,21 @@ int
 main (int argc, char *argv[])
 {
 	GtkWidget *dialog;
-	gchar *config_file;
 	char *command;
 	char *version;
 	char *ret;
 	const char *message;
 	poptContext ctx;
 	const char **args;
-	GnomeProgram *program;
+	int nextopt;
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	program = gnome_program_init ("gdmflexiserver", VERSION, 
-				      LIBGNOMEUI_MODULE /* module_info */,
-				      argc, argv,
-				      GNOME_PARAM_POPT_TABLE, options,
-				      NULL);
-	g_object_get (G_OBJECT (program),
-		      GNOME_PARAM_POPT_CONTEXT, &ctx,
-		      NULL);	
+	gtk_init(&argc, &argv);
+	ctx = poptGetContext(NULL, argc, (const char**)argv, options, 0);
+	while ((nextopt = poptGetNextOpt(ctx)) > 0 || nextopt == POPT_ERROR_BADOPT);
 
 	if (monte_carlo_pi) {
 		calc_pi ();
@@ -780,12 +732,6 @@ main (int argc, char *argv[])
 		return 1;
 	}
 
-	config_file = gdm_common_get_config_file ();
-	if (config_file == NULL) {
-		g_print (_("Could not access GDM configuration file.\n"));
-		exit (0);
-	}
-
 	if (send_command != NULL) {
 		if (authenticate)
 			auth_cookie = gdmcomm_get_auth_cookie ();
@@ -818,7 +764,6 @@ main (int argc, char *argv[])
 
 		if (ret != NULL) {
 			g_print ("%s\n", ret);
-			g_free (config_file);
 			return 0;
 		} else {
 			dialog = ve_hig_dialog_new
@@ -833,7 +778,6 @@ main (int argc, char *argv[])
 			gtk_widget_show_all (dialog);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
-			g_free (config_file);
 			return 1;
 		}
 	}
@@ -862,7 +806,6 @@ main (int argc, char *argv[])
 			gtk_widget_show_all (dialog);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
-			g_free (config_file);
 			return 1;
 		}
 		command = g_strdup_printf (GDM_SUP_FLEXI_XNEST " %s %d %s %s",
@@ -889,11 +832,10 @@ main (int argc, char *argv[])
 			gtk_widget_show_all (dialog);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
-			g_free (config_file);
 			return 1;
 		}
 
-		read_servers (config_file);
+		read_servers ();
 		server = choose_server ();
 		if (server == NULL)
 			command = g_strdup (GDM_SUP_FLEXI_XSERVER);
@@ -903,8 +845,6 @@ main (int argc, char *argv[])
 		version = "2.2.4.0";
 	}
 
-	g_free (config_file);
-
 	ret = gdmcomm_call_gdm (command, auth_cookie, version, 5);
 	g_free (command);
 
