@@ -32,6 +32,7 @@
 #define PW_ENTRY_SIZE GDM_MAX_PASS
 #endif
 
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <libgnomecanvas/libgnomecanvas.h>
@@ -63,9 +64,7 @@ gboolean DOING_GDM_DEVELOPMENT = FALSE;
 GtkWidget *window;
 GtkWidget *canvas;
 
-gboolean GDM_IS_LOCAL = FALSE;
-
-gint greeter_current_delay = 0;
+gboolean GDM_IS_LOCAL          = FALSE;
 static gboolean ignore_buttons = FALSE;
 
 /* FIXME: hack */
@@ -73,6 +72,7 @@ GreeterItemInfo *welcome_string_info = NULL;
 
 extern gboolean session_dir_whacked_out;
 extern gboolean require_quarter;
+extern gint gdm_timed_delay;
 
 gboolean greeter_probably_login_prompt = FALSE;
 
@@ -181,8 +181,11 @@ greeter_ctrl_handler (GIOChannel *source,
     case GDM_NOECHO:
         g_io_channel_read_chars (source, buf, PIPE_SIZE-1, &len, NULL);
 	buf[len-1] = '\0';
-
 	tmp = ve_locale_to_utf8 (buf);
+
+	if (tmp != NULL && strcmp (tmp, _("Password:")) == 0)
+		greeter_probably_login_prompt = FALSE;
+
 	greeter_ignore_buttons (FALSE);
 	greeter_item_pam_prompt (tmp, PW_ENTRY_SIZE, FALSE);
 	g_free (tmp);
@@ -567,8 +570,8 @@ verify_gdm_version (void)
     
       msg =  g_strdup_printf (_("The greeter version (%s) does not match the daemon "
                                 "version.  "
-                                "You have probably just upgraded gdm.  "
-                                "Please restart the gdm daemon or the computer."),
+                                "You have probably just upgraded GDM.  "
+                                "Please restart the GDM daemon or the computer."),
                               VERSION);
     
       dialog = ve_hig_dialog_new (NULL /* parent */,
@@ -602,8 +605,8 @@ verify_gdm_version (void)
     
       msg = g_strdup_printf (_("The greeter version (%s) does not match the daemon "
                                "version. "
-                               "You have probably just upgraded gdm. "
-                               "Please restart the gdm daemon or the computer."),
+                               "You have probably just upgraded GDM. "
+                               "Please restart the GDM daemon or the computer."),
                              VERSION);
     
       dialog = ve_hig_dialog_new (NULL /* parent */,
@@ -651,8 +654,8 @@ verify_gdm_version (void)
     
       msg = g_strdup_printf (_("The greeter version (%s) does not match the daemon "
                                "version (%s).  "
-                               "You have probably just upgraded gdm.  "
-                               "Please restart the gdm daemon or the computer."),
+                               "You have probably just upgraded GDM.  "
+                               "Please restart the GDM daemon or the computer."),
                              VERSION, gdm_version);
     
       dialog = ve_hig_dialog_new (NULL /* parent */,
@@ -700,7 +703,7 @@ verify_gdm_version (void)
 static void
 gdm_set_welcomemsg (void)
 {
-	char *welcomemsg = gdm_get_welcomemsg ();
+	char *welcomemsg = gdm_common_get_welcomemsg ();
 
 	if (welcome_string_info->data.text.orig_text != NULL)
 		g_free (welcome_string_info->data.text.orig_text);
@@ -720,27 +723,28 @@ greeter_reread_config (int sig, gpointer data)
 	    gdm_config_reload_string (GDM_KEY_GRAPHICAL_THEME_DIR) ||
 	    gdm_config_reload_string (GDM_KEY_GTKRC) ||
 	    gdm_config_reload_string (GDM_KEY_GTK_THEME) ||
-	    gdm_config_reload_int    (GDM_KEY_XINERAMA_SCREEN) ||
-	    gdm_config_reload_bool   (GDM_KEY_ENTRY_CIRCLES) ||
-	    gdm_config_reload_bool   (GDM_KEY_ENTRY_INVISIBLE) ||
-	    gdm_config_reload_bool   (GDM_KEY_SHOW_XTERM_FAILSAFE) ||
-	    gdm_config_reload_bool   (GDM_KEY_SHOW_GNOME_FAILSAFE) ||
-	    gdm_config_reload_bool   (GDM_KEY_INCLUDE_ALL) ||
 	    gdm_config_reload_string (GDM_KEY_INCLUDE) ||
 	    gdm_config_reload_string (GDM_KEY_EXCLUDE) ||
 	    gdm_config_reload_string (GDM_KEY_SESSION_DESKTOP_DIR) ||
 	    gdm_config_reload_string (GDM_KEY_LOCALE_FILE) ||
-	    gdm_config_reload_bool   (GDM_KEY_SYSTEM_MENU) ||
 	    gdm_config_reload_string (GDM_KEY_HALT) ||
 	    gdm_config_reload_string (GDM_KEY_REBOOT) ||
 	    gdm_config_reload_string (GDM_KEY_SUSPEND) ||
 	    gdm_config_reload_string (GDM_KEY_CONFIGURATOR) ||
 	    gdm_config_reload_string (GDM_KEY_INFO_MSG_FILE) ||
 	    gdm_config_reload_string (GDM_KEY_INFO_MSG_FONT) ||
+	    gdm_config_reload_string (GDM_KEY_TIMED_LOGIN) ||
+	    gdm_config_reload_int    (GDM_KEY_XINERAMA_SCREEN) ||
+	    gdm_config_reload_int    (GDM_KEY_TIMED_LOGIN_DELAY) ||
+	    gdm_config_reload_bool   (GDM_KEY_ENTRY_CIRCLES) ||
+	    gdm_config_reload_bool   (GDM_KEY_ENTRY_INVISIBLE) ||
+	    gdm_config_reload_bool   (GDM_KEY_SHOW_XTERM_FAILSAFE) ||
+	    gdm_config_reload_bool   (GDM_KEY_SHOW_GNOME_FAILSAFE) ||
+	    gdm_config_reload_bool   (GDM_KEY_INCLUDE_ALL) ||
+	    gdm_config_reload_bool   (GDM_KEY_SYSTEM_MENU) ||
 	    gdm_config_reload_bool   (GDM_KEY_CONFIG_AVAILABLE) ||
 	    gdm_config_reload_bool   (GDM_KEY_CHOOSER_BUTTON) ||
-	    gdm_config_reload_bool   (GDM_KEY_TIMED_LOGIN_ENABLE) ||
-	    gdm_config_reload_int    (GDM_KEY_TIMED_LOGIN_DELAY)) {
+	    gdm_config_reload_bool   (GDM_KEY_TIMED_LOGIN_ENABLE)) {
 
 		/* Set busy cursor */
 		gdm_common_setup_cursor (GDK_WATCH);
@@ -803,14 +807,14 @@ get_theme_file (const char *in, char **theme_dir)
       dir = NULL;
       if (DOING_GDM_DEVELOPMENT)
         {
-	  if (access (in, F_OK) == 0)
+	  if (g_access (in, F_OK) == 0)
 	    {
 	      dir = g_strdup (in);
 	    }
 	  else
 	    {
               dir = g_build_filename ("themes", in, NULL);
-	      if (access (dir, F_OK) != 0)
+	      if (g_access (dir, F_OK) != 0)
 	        {
 	          g_free (dir);
 	          dir = NULL;
@@ -824,11 +828,11 @@ get_theme_file (const char *in, char **theme_dir)
   *theme_dir = dir;
 
   info = g_build_filename (dir, "GdmGreeterTheme.desktop", NULL);
-  if (access (info, F_OK) != 0) {
+  if (g_access (info, F_OK) != 0) {
 	  g_free (info);
 	  info = g_build_filename (dir, "GdmGreeterTheme.info", NULL);
   }
-  if (access (info, F_OK) != 0)
+  if (g_access (info, F_OK) != 0)
     {
       char *base = g_path_get_basename (in);
       /* just guess the name, we have no info about the theme at
@@ -981,7 +985,7 @@ main (int argc, char *argv[])
   if (ve_string_empty (bg_color)) {
     bg_color = gdm_config_get_string (GDM_KEY_BACKGROUND_COLOR);
   }
-  setup_background_color (bg_color);
+  gdm_common_setup_background_color (bg_color);
   greeter_session_init ();
 
   ve_signal_add (SIGHUP, greeter_reread_config, NULL);
@@ -1049,6 +1053,12 @@ main (int argc, char *argv[])
 			       gdm_wm_screen.height);
   gtk_container_add (GTK_CONTAINER (window), canvas);
 
+ /*
+  * Initialize the value with the default value so the first time it
+  * is displayed it doesn't show as 0.
+  */
+  gdm_timed_delay = gdm_config_get_int (GDM_KEY_TIMED_LOGIN_DELAY);
+
   if (g_getenv ("GDM_THEME") != NULL)
      gdm_graphical_theme = g_strdup (g_getenv ("GDM_THEME"));
   else if (gdm_config_get_bool (GDM_KEY_GRAPHICAL_THEME_RAND))
@@ -1186,7 +1196,7 @@ main (int argc, char *argv[])
 				  _("The GTK+ greeter could not be started.  "
 				    "This display will abort and you may "
 				    "have to login another way and fix the "
-				    "installation of gdm"),
+				    "installation of GDM"),
 				  "");
     
       gtk_widget_show_all (dialog);
@@ -1320,6 +1330,7 @@ main (int argc, char *argv[])
      gdm_config_get_string (GDM_KEY_INFO_MSG_FONT));
 
   gdm_common_setup_cursor (GDK_LEFT_PTR);
+  gdm_common_post_display_launch ();
   gtk_main ();
 
   return 0;
