@@ -20,13 +20,12 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <syslog.h>
 #include <unistd.h>
 #include <dirent.h>
 #include <string.h>
 
 #include <gtk/gtk.h>
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #include "gdm.h"
 #include "gdmwm.h"
@@ -166,7 +165,7 @@ greeter_session_lookup (const char *saved_session)
 	       * irrelevant, we are in "switchdesk mode" and the relevant
 	       * thing is the saved session in .Xclients
 	       */
-	      if (access ("/usr/bin/switchdesk", F_OK) == 0)
+	      if (g_access ("/usr/bin/switchdesk", F_OK) == 0)
 	        {
 	          firstmsg = g_strdup_printf (_("You have chosen %s for this "
 	                                        "session"),
