@@ -19,13 +19,12 @@
 #include "config.h"
 
 #include <gtk/gtk.h>
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 #include "greeter.h"
 #include "greeter_configuration.h"
 #include "greeter_system.h"
 #include "greeter_item.h"
 
-#include <syslog.h>
 #include <unistd.h>
 
 #include "gdm.h"
@@ -48,7 +47,7 @@ bin_exists (const char *command)
 	/* Note, check only for existance, not for executability */
 	bin = ve_first_word (command);
 	if (bin != NULL &&
-	    access (bin, F_OK) == 0) {
+	    g_access (bin, F_OK) == 0) {
 		g_free (bin);
 		return TRUE;
 	} else {
