@@ -31,8 +31,7 @@ GtkWidget *	ve_hig_dialog_new (GtkWindow      *parent,
 				   GtkDialogFlags flags,
 				   GtkMessageType type,
 				   GtkButtonsType buttons,
-				   const gchar    *header,
-				   const gchar    *messagefmt,
-				   ...) G_GNUC_PRINTF (6, 7);
+				   const gchar    *primary_message,
+				   const gchar    *secondary_message);
 
 #endif /* VE_MISCUI_H */
