@@ -54,7 +54,7 @@ ve_find_file (const char *filename, const GList *directories)
 		pathv = g_strsplit (path, ":", 0);
 		for (i = 0; pathv[i] != NULL; i++) {
 			s = g_build_filename (pathv[i], "share", filename, NULL);
-			if (access (s, F_OK) == 0) {
+			if (g_access (s, F_OK) == 0) {
 				g_strfreev (pathv);
 				return s;
 			}
@@ -62,7 +62,7 @@ ve_find_file (const char *filename, const GList *directories)
 			s = g_build_filename (pathv[i], "share",
 					      g_get_prgname (),
 					      filename, NULL);
-			if (access (s, F_OK) == 0) {
+			if (g_access (s, F_OK) == 0) {
 				g_strfreev (pathv);
 				return s;
 			}
